# Table of Contents

- [automations-webhooks](<./automations-webhooks.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Creating an Automation with a Webhook Action](<./Creating-an-Automation-with-a-Webhook-Action.md>)
  - [Step 1: Create an Automation](<./Creating-an-Automation-with-a-Webhook-Action/Step-1-Create-an-Automation.md>)
  - [Step 2: Create a Webhook](<./Creating-an-Automation-with-a-Webhook-Action/Step-2-Create-a-Webhook.md>)
  - [Option 1: Create a Webhook in the Administration Area](<./Creating-an-Automation-with-a-Webhook-Action/Option-1-Create-a-Webhook-in-the-Administration-Area.md>)
  - [Option 2: Create a Webhook Subscription Through the API](<./Creating-an-Automation-with-a-Webhook-Action/Option-2-Create-a-Webhook-Subscription-Through-the-API.md>)
  - [Was this page helpful?](<./Creating-an-Automation-with-a-Webhook-Action/Was-this-page-helpful.md>)
